summaryrefslogtreecommitdiff
path: root/pcr/youtube-viewer/libre.patch
blob: 491b34ee3cfcc0f92a8e5979ea72437a5c4a4d50 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
diff --git a/lib/WWW/YoutubeViewer.pm b/lib/WWW/YoutubeViewer.pm
index a68b11c..bdacb08 100644
--- a/lib/WWW/YoutubeViewer.pm
+++ b/lib/WWW/YoutubeViewer.pm
@@ -535,10 +535,10 @@ sub get_video_tops {
 sub _get_formats_from_ytdl {
     my ($self, $videoID) = @_;
 
-    ((state $x = $self->proxy_system('youtube-dl', '--version')) == 0)
+    ((state $x = $self->proxy_system('avideo', '--version')) == 0)
       || return;
 
-    my $json = $self->proxy_stdout('youtube-dl', '--all-formats', '--dump-single-json',
+    my $json = $self->proxy_stdout('avideo', '--all-formats', '--dump-single-json',
                                    quotemeta("https://www.youtube.com/watch?v=" . $videoID));
 
     my @array;
@@ -705,7 +705,7 @@ sub get_streaming_urls {
         Data::Dump::pp(\@caption_urls);
     }
 
     # Try again with youtube-dl
     if (!@streaming_urls or $info{status} =~ /fail|error/i) {
         @streaming_urls = $self->_get_formats_from_ytdl($videoID);
     }
@@ -705,7 +705,7 @@ sub get_streaming_urls {
     }
 
-    # Try again with youtube-dl
+    # Try again with avideo
     if (!@streaming_urls or $info{status} =~ /fail|error/i) {
         @streaming_urls = $self->_get_formats_from_ytdl($videoID);